Introduction
============

``collective.solr`` integrates the `Plone`_ CMS with the `Solr`_ search engine.

Apache Solr is based on Lucene and is *the* enterprise open source search engine.
It powers the search of sites like Twitter, the Apple and iTunes Stores, Wikipedia, Netflix and many more.

Solr does not only scale to any level of content, but provides rich search functionality,
like faceting, geospatial search, suggestions, spelling corrections,
indexing of binary formats and a whole variety of powerful tools to configure custom search solutions.
It has integrated clustering and load-balancing to provide a high level of robustness.

``collective.solr`` comes with a default configuration and setup of Solr that makes it extremely easy to get started,
yet provides a vastly superior search quality compared to Plone's integrated text search based on ``ZCTextIndex``.

.. include:: indexes.rst
